==> mycssadmin_1.0.0.tar.gz: mycssadmin/admin/mycssadmin.php <==
<?php
// mycssadmin ver 1.0.0
//  ------------------------------------------------------------------------ //
//                   This module; Copyright (c) 2005 gusagi                  //
//                        <http://good-tea.ddo.jp/trpg>                      //
//  ------------------------------------------------------------------------ //

//*****************************************************************************/
// 
//*****************************************************************************/
// ¾ΥץȤƤӽФ줿ǧ
// ƤӽФ줿ϡưʸȽ˻Ѥ
$replace_array = array( '\\' => '/', '\\.\\' => '\\', '/./' => '/' );
if ( strtr($_SERVER['SCRIPT_FILENAME'], $replace_array) !== strtr(__FILE__, '\\', '/') ) {
	define( 'MYCSSADMIN_CALLED', true );
}
require_once( dirname(dirname(__FILE__)) .'/include/mycssadmin.inc.php' );
if ( ! defined('MYCSSADMIN_CALLED') ) {
	require_once( XOOPS_ROOT_PATH .'/include/cp_header.php' );
	require_once( XOOPS_ROOT_PATH .'/class/template.php' );
	include_once( XOOPS_ROOT_PATH .'/modules/system/constants.php' ) ;
	require_once( $mod_path .'/include/gtickets.php' );

	// check access right (needs system_admin of BLOCK)
	$sysperm_handler =& xoops_gethandler('groupperm');
	if (!$sysperm_handler->checkRight('system_admin', XOOPS_SYSTEM_BLOCK, $xoopsUser->getGroups())) redirect_header( XOOPS_URL.'/user.php' , 1 , _NOPERM ) ;
	
}
// åν
unset( $_SESSION['cssadmin_op'] );

// ƥץ졼Ȥ
$cssTpl =& new XoopsTpl;
$cssTpl->error_reporting = error_reporting();
$cssTpl->template_dir = $mod_path.'/admin/templates/';

//*****************************************************************************/
// ֥åμ
//*****************************************************************************/
$blocks = array();
if ( empty($current_module) ) {
	// 
	$current_module = array();
	$xoopsDB = & Database::getInstance();
	$modulesTbl = $xoopsDB->prefix( 'modules' );
	$sql = "SELECT mid, name, dirname FROM $modulesTbl WHERE dirname = '$mod_name'";
	$result = $xoopsDB->query( $sql );
	if ( $myrow = $xoopsDB->fetchArray($result) ) {
		$mid = intval( $myrow['mid'] );
		$name = $myrow['name'];
		$dirname = $myrow['dirname'];
		$current_module['mid'] = $mid;
		$current_module['name'] = $name;
		$current_module['dirname'] = $dirname;
	}
} else {
	$mid = intval( $mid );
}

include( dirname(dirname(__FILE__)) .'/class/mycssadmin.class.php' );
$CssadminBlocks->setBlockList( $mid );
$CssadminBlocks->setBlockDbCss( $mid );
$CssadminBlocks->setBlockDirCss( $dirname );
$blocks = $CssadminBlocks->getBlocks();

//*****************************************************************************/
// ˥
//*****************************************************************************/
include( dirname(dirname(__FILE__)) .'/class/mycssadmin_display.class.php' );
$current_module4disp = $CssadminDisplay->sanitizeArray4disp( $current_module );
$blocks4disp = $CssadminDisplay->sanitizeArray4disp( $blocks );

//*****************************************************************************/
// ɽ
//*****************************************************************************/
if ( ! defined('MYCSSADMIN_CALLED') ) {
	// ѥإåθƤӽФ
	xoops_cp_header();
	// ̾˥塼θƤӽФ
	if( file_exists( './mymenu.php' ) ) include( './mymenu.php' );

	// ԤΥ
	$action = $mod_url .'/admin/mycssadmin_save.php';
}
$cssTpl->assign( 'action', $action );
// ֥åΥ
$cssTpl->assign( 'blocks', $blocks4disp );
$cssTpl->assign( 'block_count', count($blocks4disp) );
$cssTpl->assign( 'current_module', $current_module4disp );
// 󥿥åȤΥ
$ticket = $xoopsGTicket->getTicketHtml( __LINE__ , 1800 , $mod_name );
$cssTpl->assign( 'ticket', $ticket );
// ƥץ졼Ȥɽ
$cssTpl->display( 'mycssadmin.html' );

//*****************************************************************************/
// λ
//*****************************************************************************/ 
// åؤγǼ
$_SESSION['cssadmin_blocks'] = $blocks;
$_SESSION['cssadmin_op'] = 'save_blocks_css';
if ( ! defined('MYCSSADMIN_CALLED') ) {
	// ѥեåθƤӽФ
	xoops_cp_footer();
}

?>

==> mycssadmin_1.0.3.tar.gz: mycssadmin/admin/mycssadmin.php <==
<?php
// mycssadmin ver 1.0.3
//  ------------------------------------------------------------------------ //
//                   This module; Copyright (c) 2005 gusagi                  //
//                        <http://good-tea.ddo.jp/trpg>                      //
//  ------------------------------------------------------------------------ //

//*****************************************************************************/
// 
//*****************************************************************************/
// ¾ΥץȤƤӽФ줿ǧ
// ƤӽФ줿ϡưʸȽ˻Ѥ
$replace_array = array( '\\' => '/', '\\.\\' => '/', '/./' => '/' );
if ( strtr($_SERVER['SCRIPT_FILENAME'], $replace_array) !== strtr(__FILE__, '\\', '/') ) {
	define( 'MYCSSADMIN_CALLED', true );
}
require_once( dirname(dirname(__FILE__)) .'/include/mycssadmin.inc.php' );
if ( ! defined('MYCSSADMIN_CALLED') ) {
	require_once( XOOPS_ROOT_PATH .'/include/cp_header.php' );
	require_once( XOOPS_ROOT_PATH .'/class/template.php' );
	include_once( XOOPS_ROOT_PATH .'/modules/system/constants.php' ) ;
	require_once( $mod_path .'/include/gtickets.php' );

	// check access right (needs system_admin of BLOCK)
	$sysperm_handler =& xoops_gethandler('groupperm');
	if (!$sysperm_handler->checkRight('system_admin', XOOPS_SYSTEM_BLOCK, $xoopsUser->getGroups())) redirect_header( XOOPS_URL.'/user.php' , 1 , _NOPERM ) ;
	
}
// åν
unset( $_SESSION['cssadmin_op'] );

// ƥץ졼Ȥ
$cssTpl =& new XoopsTpl;
$cssTpl->error_reporting = error_reporting();
$cssTpl->template_dir = $mod_path.'/admin/templates/';

//*****************************************************************************/
// ֥åμ
//*****************************************************************************/
$blocks = array();
if ( empty($current_module) ) {
	// 
	$current_module = array();
	$xoopsDB = & Database::getInstance();
	$modulesTbl = $xoopsDB->prefix( 'modules' );
	$sql = "SELECT mid, name, dirname FROM $modulesTbl WHERE dirname = '$mod_name'";
	$result = $xoopsDB->query( $sql );
	if ( $myrow = $xoopsDB->fetchArray($result) ) {
		$mid = intval( $myrow['mid'] );
		$name = $myrow['name'];
		$dirname = $myrow['dirname'];
		$current_module['mid'] = $mid;
		$current_module['name'] = $name;
		$current_module['dirname'] = $dirname;
	}
} else {
	$mid = intval( $mid );
}

include( dirname(dirname(__FILE__)) .'/class/mycssadmin.class.php' );
$CssadminBlocks->setBlockList( $mid );
$CssadminBlocks->setBlockDbCss( $mid );
$CssadminBlocks->setBlockDirCss( $dirname );
$blocks = $CssadminBlocks->getBlocks();

//*****************************************************************************/
// ˥
//*****************************************************************************/
include( dirname(dirname(__FILE__)) .'/class/mycssadmin_display.class.php' );
$current_module4disp = $CssadminDisplay->sanitizeArray4disp( $current_module );
$blocks4disp = $CssadminDisplay->sanitizeArray4disp( $blocks );

//*****************************************************************************/
// ɽ
//*****************************************************************************/
if ( ! defined('MYCSSADMIN_CALLED') ) {
	// ѥإåθƤӽФ
	xoops_cp_header();
	// ̾˥塼θƤӽФ
	if( file_exists( './mymenu.php' ) ) include( './mymenu.php' );

	// ԤΥ
	$action = $mod_url .'/admin/mycssadmin_save.php';
}
$cssTpl->assign( 'action', $action );
// ֥åΥ
$cssTpl->assign( 'blocks', $blocks4disp );
$cssTpl->assign( 'block_count', count($blocks4disp) );
$cssTpl->assign( 'current_module', $current_module4disp );
// 󥿥åȤΥ
$ticket = $xoopsGTicket->getTicketHtml( __LINE__ , 1800 , $mod_name );
$cssTpl->assign( 'ticket', $ticket );
// ƥץ졼Ȥɽ
$cssTpl->display( 'mycssadmin.html' );

//*****************************************************************************/
// λ
//*****************************************************************************/ 
// åؤγǼ
$_SESSION['cssadmin_blocks'] = $blocks;
$_SESSION['cssadmin_op'] = 'save_blocks_css';
if ( ! defined('MYCSSADMIN_CALLED') ) {
	// ѥեåθƤӽФ
	xoops_cp_footer();
}

?>
